@@ -75,7 +75,13 @@ python_version_matches = expected_python_version == actual_python_version
 
 log_message('python_prefix_matches = %r', python_prefix_matches)
 log_message('python_version_matches = %r', python_version_matches)
+print("dafsdfasdfadsf")
+print("FAST_PYTHON_PREFIX:", os.environ.get('FAST_PYTHON_PREFIX'))
+print("actual_python_prefix:", os.path.realpath(os.path.normpath(sys.prefix)))
+print("FAST_PYTHON_VERSION:", os.environ.get('FAST_PYTHON_VERSION'))
+print("actual_python_version:", actual_python_version)
 print("666")
+print(python_prefix_matches, python_version_matches)
 if python_prefix_matches and python_version_matches:
 
     config_file = os.environ.get('FAST_CONFIG_FILE', None)
